### scmrepo

[![Tests](https://github.com/iterative/scmrepo/workflows/Tests/badge.svg)](https://github.com/iterative/scmrepo/actions?workflow=Tests)

SCM wrapper and fsspec filesystem for Git for use in DVC
